==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/OnPremiseSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * On-premise settings.
 * @property computeSettings Compute settings.
 * @property facilitySettings Facility settings.
 * @property laborSettings Labour settings.
 * @property managementSettings Management settings.
 * @property networkSettings Network settings.
 * @property securitySettings Security settings.
 * @property storageSettings Storage settings.
 */
public data class OnPremiseSettingsArgs(
    public val computeSettings: Output<ComputeSettingsArgs>,
    public val facilitySettings: Output<FacilitySettingsArgs>,
    public val laborSettings: Output<LaborSettingsArgs>,
    public val managementSettings: Output<ManagementSettingsArgs>? = null,
    public val networkSettings: Output<NetworkSettingsArgs>,
    public val securitySettings: Output<SecuritySettingsArgs>,
    public val storageSettings: Output<StorageSettingsArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs.builder()
            .computeSettings(computeSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .facilitySettings(facilitySettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .laborSettings(laborSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .managementSettings(
                managementSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .networkSettings(networkSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .securitySettings(securitySettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageSettings(
                storageSettings.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OnPremiseSettingsArgs].
 */
@PulumiTagMarker
public class OnPremiseSettingsArgsBuilder internal constructor() {
    private var computeSettings: Output<ComputeSettingsArgs>? = null

    private var facilitySettings: Output<FacilitySettingsArgs>? = null

    private var laborSettings: Output<LaborSettingsArgs>? = null

    private var managementSettings: Output<ManagementSettingsArgs>? = null

    private var networkSettings: Output<NetworkSettingsArgs>? = null

    private var securitySettings: Output<SecuritySettingsArgs>? = null

    private var storageSettings: Output<StorageSettingsArgs>? = null

    /**
     * @param value Compute settings.
     */
    @JvmName("akeyprpipgpjmyok")
    public suspend fun computeSettings(`value`: Output<ComputeSettingsArgs>) {
        this.computeSettings = value
    }

    /**
     * @param value Facility settings.
     */
    @JvmName("fobgkkbrvtqeyfes")
    public suspend fun facilitySettings(`value`: Output<FacilitySettingsArgs>) {
        this.facilitySettings = value
    }

    /**
     * @param value Labour settings.
     */
    @JvmName("etmugbnhvomjiebc")
    public suspend fun laborSettings(`value`: Output<LaborSettingsArgs>) {
        this.laborSettings = value
    }

    /**
     * @param value Management settings.
     */
    @JvmName("enxxtmledupfnqfe")
    public suspend fun managementSettings(`value`: Output<ManagementSettingsArgs>) {
        this.managementSettings = value
    }

    /**
     * @param value Network settings.
     */
    @JvmName("hljqmfsnjfboyics")
    public suspend fun networkSettings(`value`: Output<NetworkSettingsArgs>) {
        this.networkSettings = value
    }

    /**
     * @param value Security settings.
     */
    @JvmName("asgasxgasoxwmptt")
    public suspend fun securitySettings(`value`: Output<SecuritySettingsArgs>) {
        this.securitySettings = value
    }

    /**
     * @param value Storage settings.
     */
    @JvmName("iwsndgexjqpmwwsh")
    public suspend fun storageSettings(`value`: Output<StorageSettingsArgs>) {
        this.storageSettings = value
    }

    /**
     * @param value Compute settings.
     */
    @JvmName("vruspwuurveonobq")
    public suspend fun computeSettings(`value`: ComputeSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeSettings = mapped
    }

    /**
     * @param argument Compute settings.
     */
    @JvmName("rsdwhccxmmxxaarg")
    public suspend fun computeSettings(argument: suspend ComputeSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.computeSettings = mapped
    }

    /**
     * @param value Facility settings.
     */
    @JvmName("iptwxjeliywvjymo")
    public suspend fun facilitySettings(`value`: FacilitySettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.facilitySettings = mapped
    }

    /**
     * @param argument Facility settings.
     */
    @JvmName("ktnuqblrvlcdoukg")
    public suspend fun facilitySettings(argument: suspend FacilitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = FacilitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facilitySettings = mapped
    }

    /**
     * @param value Labour settings.
     */
    @JvmName("xsaayravsoqcsbmc")
    public suspend fun laborSettings(`value`: LaborSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.laborSettings = mapped
    }

    /**
     * @param argument Labour settings.
     */
    @JvmName("qlqmmmeyynbsxumn")
    public suspend fun laborSettings(argument: suspend LaborSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = LaborSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.laborSettings = mapped
    }

    /**
     * @param value Management settings.
     */
    @JvmName("mynoyyeuduyykqau")
    public suspend fun managementSettings(`value`: ManagementSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementSettings = mapped
    }

    /**
     * @param argument Management settings.
     */
    @JvmName("ywetjchobwrdtyng")
    public suspend
    fun managementSettings(argument: suspend ManagementSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managementSettings = mapped
    }

    /**
     * @param value Network settings.
     */
    @JvmName("ukbovyrdsgtfchwg")
    public suspend fun networkSettings(`value`: NetworkSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkSettings = mapped
    }

    /**
     * @param argument Network settings.
     */
    @JvmName("smtcaqwvecwimgru")
    public suspend fun networkSettings(argument: suspend NetworkSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSettings = mapped
    }

    /**
     * @param value Security settings.
     */
    @JvmName("golfeulkocaxgnxt")
    public suspend fun securitySettings(`value`: SecuritySettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securitySettings = mapped
    }

    /**
     * @param argument Security settings.
     */
    @JvmName("ngrtheykbuijdtic")
    public suspend fun securitySettings(argument: suspend SecuritySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SecuritySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securitySettings = mapped
    }

    /**
     * @param value Storage settings.
     */
    @JvmName("wyydmqeammobvouy")
    public suspend fun storageSettings(`value`: StorageSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage settings.
     */
    @JvmName("dvlvyylertinayln")
    public suspend fun storageSettings(argument: suspend StorageSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = StorageSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    internal fun build(): OnPremiseSettingsArgs = OnPremiseSettingsArgs(
        computeSettings = computeSettings ?: throw PulumiNullFieldException("computeSettings"),
        facilitySettings = facilitySettings ?: throw PulumiNullFieldException("facilitySettings"),
        laborSettings = laborSettings ?: throw PulumiNullFieldException("laborSettings"),
        managementSettings = managementSettings,
        networkSettings = networkSettings ?: throw PulumiNullFieldException("networkSettings"),
        securitySettings = securitySettings ?: throw PulumiNullFieldException("securitySettings"),
        storageSettings = storageSettings ?: throw PulumiNullFieldException("storageSettings"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/OnPremiseSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * On-premise settings.
 * @property computeSettings Compute settings.
 * @property facilitySettings Facility settings.
 * @property laborSettings Labour settings.
 * @property managementSettings Management settings.
 * @property networkSettings Network settings.
 * @property securitySettings Security settings.
 * @property storageSettings Storage settings.
 */
public data class OnPremiseSettingsArgs(
    public val computeSettings: Output<ComputeSettingsArgs>,
    public val facilitySettings: Output<FacilitySettingsArgs>,
    public val laborSettings: Output<LaborSettingsArgs>,
    public val managementSettings: Output<ManagementSettingsArgs>? = null,
    public val networkSettings: Output<NetworkSettingsArgs>,
    public val securitySettings: Output<SecuritySettingsArgs>,
    public val storageSettings: Output<StorageSettingsArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.OnPremiseSettingsArgs.builder()
            .computeSettings(computeSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .facilitySettings(facilitySettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .laborSettings(laborSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .managementSettings(
                managementSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .networkSettings(networkSettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .securitySettings(securitySettings.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageSettings(
                storageSettings.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OnPremiseSettingsArgs].
 */
@PulumiTagMarker
public class OnPremiseSettingsArgsBuilder internal constructor() {
    private var computeSettings: Output<ComputeSettingsArgs>? = null

    private var facilitySettings: Output<FacilitySettingsArgs>? = null

    private var laborSettings: Output<LaborSettingsArgs>? = null

    private var managementSettings: Output<ManagementSettingsArgs>? = null

    private var networkSettings: Output<NetworkSettingsArgs>? = null

    private var securitySettings: Output<SecuritySettingsArgs>? = null

    private var storageSettings: Output<StorageSettingsArgs>? = null

    /**
     * @param value Compute settings.
     */
    @JvmName("hcuchlexokktqwsl")
    public suspend fun computeSettings(`value`: Output<ComputeSettingsArgs>) {
        this.computeSettings = value
    }

    /**
     * @param value Facility settings.
     */
    @JvmName("gosviryaxdtcsfdf")
    public suspend fun facilitySettings(`value`: Output<FacilitySettingsArgs>) {
        this.facilitySettings = value
    }

    /**
     * @param value Labour settings.
     */
    @JvmName("jkbgmighqlfhygko")
    public suspend fun laborSettings(`value`: Output<LaborSettingsArgs>) {
        this.laborSettings = value
    }

    /**
     * @param value Management settings.
     */
    @JvmName("ptmtelexpgcjotcf")
    public suspend fun managementSettings(`value`: Output<ManagementSettingsArgs>) {
        this.managementSettings = value
    }

    /**
     * @param value Network settings.
     */
    @JvmName("hjpxsnhbtacsfbnp")
    public suspend fun networkSettings(`value`: Output<NetworkSettingsArgs>) {
        this.networkSettings = value
    }

    /**
     * @param value Security settings.
     */
    @JvmName("pxhrawmrppdbqpbn")
    public suspend fun securitySettings(`value`: Output<SecuritySettingsArgs>) {
        this.securitySettings = value
    }

    /**
     * @param value Storage settings.
     */
    @JvmName("bygpqmbcieglcavm")
    public suspend fun storageSettings(`value`: Output<StorageSettingsArgs>) {
        this.storageSettings = value
    }

    /**
     * @param value Compute settings.
     */
    @JvmName("bnumqboxfggsvqhf")
    public suspend fun computeSettings(`value`: ComputeSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeSettings = mapped
    }

    /**
     * @param argument Compute settings.
     */
    @JvmName("sgkxpquprqqxmvvs")
    public suspend fun computeSettings(argument: suspend ComputeSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.computeSettings = mapped
    }

    /**
     * @param value Facility settings.
     */
    @JvmName("slpspicukaxbyyho")
    public suspend fun facilitySettings(`value`: FacilitySettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.facilitySettings = mapped
    }

    /**
     * @param argument Facility settings.
     */
    @JvmName("entimegslcctvmyp")
    public suspend fun facilitySettings(argument: suspend FacilitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = FacilitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facilitySettings = mapped
    }

    /**
     * @param value Labour settings.
     */
    @JvmName("bqinjurttxafoxac")
    public suspend fun laborSettings(`value`: LaborSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.laborSettings = mapped
    }

    /**
     * @param argument Labour settings.
     */
    @JvmName("wkvifnnwkdsvhluo")
    public suspend fun laborSettings(argument: suspend LaborSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = LaborSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.laborSettings = mapped
    }

    /**
     * @param value Management settings.
     */
    @JvmName("tmultiloksrcymnv")
    public suspend fun managementSettings(`value`: ManagementSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementSettings = mapped
    }

    /**
     * @param argument Management settings.
     */
    @JvmName("tfdegwbgpnyefdbf")
    public suspend
    fun managementSettings(argument: suspend ManagementSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managementSettings = mapped
    }

    /**
     * @param value Network settings.
     */
    @JvmName("mjkrqovtyephxmbq")
    public suspend fun networkSettings(`value`: NetworkSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkSettings = mapped
    }

    /**
     * @param argument Network settings.
     */
    @JvmName("euxnbchccobdcqiw")
    public suspend fun networkSettings(argument: suspend NetworkSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSettings = mapped
    }

    /**
     * @param value Security settings.
     */
    @JvmName("xlyxuctxcgqruxdu")
    public suspend fun securitySettings(`value`: SecuritySettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securitySettings = mapped
    }

    /**
     * @param argument Security settings.
     */
    @JvmName("eyurmlvahfvpuvsc")
    public suspend fun securitySettings(argument: suspend SecuritySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SecuritySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securitySettings = mapped
    }

    /**
     * @param value Storage settings.
     */
    @JvmName("tajcaqdkougyucus")
    public suspend fun storageSettings(`value`: StorageSettingsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage settings.
     */
    @JvmName("tqawltfcavqjtjfr")
    public suspend fun storageSettings(argument: suspend StorageSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = StorageSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    internal fun build(): OnPremiseSettingsArgs = OnPremiseSettingsArgs(
        computeSettings = computeSettings ?: throw PulumiNullFieldException("computeSettings"),
        facilitySettings = facilitySettings ?: throw PulumiNullFieldException("facilitySettings"),
        laborSettings = laborSettings ?: throw PulumiNullFieldException("laborSettings"),
        managementSettings = managementSettings,
        networkSettings = networkSettings ?: throw PulumiNullFieldException("networkSettings"),
        securitySettings = securitySettings ?: throw PulumiNullFieldException("securitySettings"),
        storageSettings = storageSettings ?: throw PulumiNullFieldException("storageSettings"),
    )
}
